@@ -1,8 +1,7 @@
 
-if (typeof exports != "undefined") {
+if (typeof exports !== "undefined") {
   var driver = require("./driver.js");
   var test = driver.test, testFail = driver.testFail;
-  var acorn = require("../acorn");
 }
 
 //------------------------------------------------------------------------------
